Coverage for dateutil\__init__.py: 0%

# Coverage for dateutil\__init__.py : 0%

## 5 statements 0 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 | # -*- coding: utf-8 -*- try: from ._version import version as __version__ except ImportError: __version__ = 'unknown' __all__ = ['easter', 'parser', 'relativedelta', 'rrule', 'tz', 'utils', 'zoneinfo']